@@ -99,7 +99,10 @@ class SnapTradeAPIClient:
         try:
             if method == "post":
                 response = requests.post(
-                    endpoint, headers=headers, params=query_params, json=data
+                    endpoint,
+                    headers=headers,
+                    params=query_params,
+                    json=data,
                 )
             elif method == "get":
                 response = requests.get(endpoint, headers=headers, params=query_params)
@@ -172,7 +175,14 @@ class SnapTradeAPIClient:
 
         return self._make_request(endpoint_name, query_params=query_params)
 
-    def get_user_login_redirect_uri(self, user_id, user_secret):
+    def get_user_login_redirect_uri(
+        self,
+        user_id,
+        user_secret,
+        broker=None,
+        immediate_redirect=False,
+        custom_redirect=None,
+    ):
         """Returns redirect uri for user to"""
         endpoint_name = "user_login_redirect_uri"
 
@@ -181,10 +191,18 @@ class SnapTradeAPIClient:
             endpoint_name, initial_params=initial_query_params
         )
 
-        return self._make_request(endpoint_name, query_params=query_params)
+        data = dict()
+        if broker:
+            data["broker"] = broker
+        if immediate_redirect:
+            data["immediateRedirect"] = True
+        if custom_redirect:
+            data["customRedirect"] = custom_redirect
+
+        return self._make_request(endpoint_name, data=data, query_params=query_params)
 
     """
-    Accounts details, holdings, activities, brokerage connection endpoints
+    Accounts details, holdings, brokerage connection endpoints
     """
 
     def get_brokerage_connections(self, user_id, user_secret):
@@ -295,6 +313,10 @@ class SnapTradeAPIClient:
 
         return self._make_request(endpoint_name, query_params=query_params)
 
+    """
+    Reporting endpoints: activities, performance
+    """
+
     def get_activities(self, user_id, user_secret, start_date=None, end_date=None):
         endpoint_name = "activities"
 
@@ -312,6 +334,39 @@ class SnapTradeAPIClient:
 
         return self._make_request(endpoint_name, query_params=query_params)
 
+    def get_performance_custom(
+        self,
+        user_id,
+        user_secret,
+        start_date,
+        end_date,
+        frequency=None,
+        account_ids=None,
+    ):
+        endpoint_name = "performance"
+
+        initial_query_params = dict(
+            userId=user_id,
+            userSecret=user_secret,
+            startDate=start_date,
+            end_date=end_date,
+        )
+
+        if frequency:
+            initial_query_params["frequency"] = frequency
+
+        if account_ids:  # Should be account IDs separated by commas
+            if type(account_ids) == list:
+                account_ids = ",".join(account_ids)
+
+            initial_query_params["accounts"] = account_ids
+
+        query_params = self.prepare_query_params(
+            endpoint_name, initial_params=initial_query_params
+        )
+
+        return self._make_request(endpoint_name, query_params=query_params)
+
     """
     Reference data endpoints
     """
@@ -322,6 +377,12 @@ class SnapTradeAPIClient:
 
         return self._make_request(endpoint_name, query_params=query_params)
 
+    def get_exchanges(self):
+        endpoint_name = "exchanges"
+        query_params = self.prepare_query_params(endpoint_name)
+
+        return self._make_request(endpoint_name, query_params=query_params)
+
     def get_currencies(self):
         endpoint_name = "currencies"
         query_params = self.prepare_query_params(endpoint_name)
